#!/usr/bin/env python

from distutils.core import setup

setup(name='bahttext',
      version='1.0',
      description='Tool for convert currency number to Thai text',
      author='Seksan Poltree',
      author_email='seksan@morange.co.th',
      url='https://github.com/morangesolution/bahttext',
      download_url='https://github.com/morangesolution/bahttext/tarball/master',
      packages=['bahttext'],
      license="BSD",
     )

